@@ -18,8 +18,9 @@ touch "$TEST_MNT/|5gp!"
 
 run_check_umount_test_dev
 
-run_check touch img img.restored img.dump
-run_check chmod a+w img img.restored img.dump
+_mktemp_local img
+_mktemp_local img.restored
+_mktemp_local img.dump
 run_check $SUDO_HELPER "$TOP/btrfs-image" -ss "$TEST_DEV" img
 run_check $SUDO_HELPER "$TOP/btrfs-image" -r img img.restored
 run_check_stdout $SUDO_HELPER "$TOP/btrfs" inspect-internal dump-tree img.restored > img.dump
